==> unifont_15.1.01.orig.tar.gz: unifont-15.1.01/doxygen/html/hex2otf_8c.js <==
var hex2otf_8c =
[
    [ "Buffer", "structBuffer.html", "structBuffer" ],
    [ "Glyph", "structGlyph.html", "structGlyph" ],
    [ "Font", "structFont.html", "structFont" ],
    [ "Table", "structTable.html", "structTable" ],
    [ "TableRecord", "structTableRecord.html", "structTableRecord" ],
    [ "Options", "structOptions.html", "structOptions" ],
    [ "addByte", "hex2otf_8c.html#a23781d23f31cfbcaf33e86e10d7cce50", null ],
    [ "ASCENDER", "hex2otf_8c.html#ad0d9350c8943e5550a14f1cff5580a6c", null ],
    [ "B0", "hex2otf_8c.html#a15c6f2a017088c5db6daac264f992a67", null ],
    [ "B1", "hex2otf_8c.html#a2177c1b55319bb7fd9015fb8b8629ead", null ],
    [ "BX", "hex2otf_8c.html#a77e92e56b5af63bc912ed4cbf5f5c585", null ],
    [ "cacheCFF32", "hex2otf_8c.html#a3aa464534b439904ec3a91db5fd313a0", null ],
    [ "defineStore", "hex2otf_8c.html#a0e5f5e7d04aec261ae28e2fca801194c", null ],
    [ "DESCENDER", "hex2otf_8c.html#a91005fb187034d042b6bad9c9b1ae7c4", null ],
    [ "flipRowBit", "hex2otf_8c.html#aa51bea432733981a06404c5f029108f7", null ],
    [ "FU", "hex2otf_8c.html#a84fd83fab1f19cfb33addaa0557c4682", null ],
    [ "FUPEM", "hex2otf_8c.html#a652fd701381105d0d34ca4084cca413c", null ],
    [ "getRowBit", "hex2otf_8c.html#a557b26ae24c6df65878422040be2e922", null ],
    [ "GLYPH_HEIGHT", "hex2otf_8c.html#a7d0a7ac24105d9c91bce2b5a1e9a1ad3", null ],
    [ "GLYPH_MAX_BYTE_COUNT", "hex2otf_8c.html#ad0f95bf4a3a4a28b173b971e246b8745", null ],
    [ "GLYPH_MAX_WIDTH", "hex2otf_8c.html#a688a4772d61221e9378e5003da51265a", null ],
    [ "MAX_GLYPHS", "hex2otf_8c.html#a1a1d1da8a5f6da54d749399b173c9bfc", null ],
    [ "MAX_NAME_IDS", "hex2otf_8c.html#a06a292e7a76c13c1fa509187a7e6577a", null ],
    [ "PRI_CP", "hex2otf_8c.html#af25acbe53b9070c1400a04c9231691bb", null ],
    [ "PW", "hex2otf_8c.html#a79e768c38f3b21419f01d2d1347523be", null ],
    [ "static_assert", "hex2otf_8c.html#abce67139ad0bc979ef080a694e60fb36", null ],
    [ "stringCount", "hex2otf_8c.html#a13f8122753a7298916b3dddc2acb389a", null ],
    [ "U16MAX", "hex2otf_8c.html#a01d5b7bf9004b7a8c920f958861d2a8e", null ],
    [ "U32MAX", "hex2otf_8c.html#a7ccab01e56208030185cefdca13e0ac8", null ],
    [ "VERSION", "hex2otf_8c.html#a1c6d5de492ac61ad29aec7aa9a436bbf", null ],
    [ "Buffer", "hex2otf_8c.html#a7feadaf37f40473cfc76921f8754c0f7", null ],
    [ "byte", "hex2otf_8c.html#a0c8186d9b9b7880309c27230bbb5e69d", null ],
    [ "Font", "hex2otf_8c.html#a6793c760667fe6bf1481f61567954c12", null ],
    [ "Glyph", "hex2otf_8c.html#a8ac383e879c9d7d9af6005444970c837", null ],
    [ "NameStrings", "hex2otf_8c.html#a07c4a43c1a36ee79c8a163298ff9adac", null ],
    [ "Options", "hex2otf_8c.html#a97fbabab590ac85657edb01474da7d50", null ],
    [ "pixels_t", "hex2otf_8c.html#ab9f46992237e1552d3ae221b2a5e95ff", null ],
    [ "Table", "hex2otf_8c.html#aaa5713bb2ecdf81c430009179b806232", null ],
    [ "ContourOp", "hex2otf_8c.html#a25218b5574c0da4a0580647c1a084f38", [
      [ "OP_CLOSE", "hex2otf_8c.html#a25218b5574c0da4a0580647c1a084f38a9e771dc35104ec1246adba881d27e372", null ],
      [ "OP_POINT", "hex2otf_8c.html#a25218b5574c0da4a0580647c1a084f38a01f5371958d06ab1411c46f72f049f45", null ]
    ] ],
    [ "FillSide", "hex2otf_8c.html#a6a06835afab662d1c9fd91960654bb8c", [
      [ "FILL_LEFT", "hex2otf_8c.html#a6a06835afab662d1c9fd91960654bb8caf18243d8ef6a7f601ae03a6cffbabadd", null ],
      [ "FILL_RIGHT", "hex2otf_8c.html#a6a06835afab662d1c9fd91960654bb8ca0bbdc63e5d0938274b80230bc55d03b8", null ]
    ] ],
    [ "LocaFormat", "hex2otf_8c.html#a7da3527c69a413194afdce359b03e1ea", [
      [ "LOCA_OFFSET16", "hex2otf_8c.html#a7da3527c69a413194afdce359b03e1eaa9c5871c30feb10df049d99bd703dfda4", null ],
      [ "LOCA_OFFSET32", "hex2otf_8c.html#a7da3527c69a413194afdce359b03e1eaad5e47b5a6bbf31be31e9b1328e7beef8", null ]
    ] ],
    [ "addTable", "hex2otf_8c.html#a1fab24bb2d2b38b68a38ec871afc3f9c", null ],
    [ "buildOutline", "hex2otf_8c.html#a5af7c9bcfd40e5b11f9d12c40966bb65", null ],
    [ "byCodePoint", "hex2otf_8c.html#a0d187cc87528ef35478afd7a68309f08", null ],
    [ "byTableTag", "hex2otf_8c.html#af1223f39e8627e0a3b0b7b533e6d0b64", null ],
    [ "cacheBuffer", "hex2otf_8c.html#a560637130747e543118ff304389fd18f", null ],
    [ "cacheBytes", "hex2otf_8c.html#a927c31a7e187d15a70667ce6b0ef296a", null ],
    [ "cacheCFFOperand", "hex2otf_8c.html#a51be7f69e0f6053772b3ddacf215df84", null ],
    [ "cacheStringAsUTF16BE", "hex2otf_8c.html#a199befd98ef9ec0ee659d82609abded4", null ],
    [ "cacheU16", "hex2otf_8c.html#a07b29528c561e5852a228c98391225f7", null ],
    [ "cacheU32", "hex2otf_8c.html#a051a88b0ac4eb063945b84e2242408ea", null ],
    [ "cacheU8", "hex2otf_8c.html#a84d7310553d31f4ec587dc001f472834", null ],
    [ "cacheZeros", "hex2otf_8c.html#a0d4560c5d562d31a33f092bb579f8397", null ],
    [ "cleanBuffers", "hex2otf_8c.html#ac947cbe076da5fbab8f5e4c1c821b7a6", null ],
    [ "defineStore", "hex2otf_8c.html#a4580a6e8cc566504bc2b852272c9434e", null ],
    [ "ensureBuffer", "hex2otf_8c.html#ae32c0f82cbb6a4d8ece0559f1c7b74f4", null ],
    [ "fail", "hex2otf_8c.html#a2f5976201b1e630a94045f04a0348572", null ],
    [ "fillBitmap", "hex2otf_8c.html#afd499a24ff34cb5c19b52df795422c12", null ],
    [ "fillBlankOutline", "hex2otf_8c.html#ab37b4f7111692f8d1163bafd2aab831e", null ],
    [ "fillCFF", "hex2otf_8c.html#a3d62aa29f94c3fa78ca4438739d64a62", null ],
    [ "fillCmapTable", "hex2otf_8c.html#a6362601eb41d051a103a1d9edcd4f284", null ],
    [ "fillGposTable", "hex2otf_8c.html#a6c1e982fdc6c51b9f84051daa2e71936", null ],
    [ "fillGsubTable", "hex2otf_8c.html#a06b8121dea15c8117b7c951ffb22fb7e", null ],
    [ "fillHeadTable", "hex2otf_8c.html#a4ac0c02117b703a71bee3dd34e2eb306", null ],
    [ "fillHheaTable", "hex2otf_8c.html#a28e889c3a36007c2e5d50a498046a6c6", null ],
    [ "fillHmtxTable", "hex2otf_8c.html#a97c9b2ae58f5989d68e639715c3f9df9", null ],
    [ "fillMaxpTable", "hex2otf_8c.html#aff4f28ce178c84c7365245ec10034433", null ],
    [ "fillNameTable", "hex2otf_8c.html#a79d8a322be9d9131b684a9ea67abe05e", null ],
    [ "fillOS2Table", "hex2otf_8c.html#ab6e3bb110dc3e55193c344cb7b56e328", null ],
    [ "fillPostTable", "hex2otf_8c.html#a0ddc03905c4918e04aa1e54a7c1716b1", null ],
    [ "fillTrueType", "hex2otf_8c.html#a326e4fa86eb32bb18e37eab8f495bd2f", null ],
    [ "freeBuffer", "hex2otf_8c.html#ac928f7761fc187ff86f33805309bec21", null ],
    [ "initBuffers", "hex2otf_8c.html#a4cebe6a72365812b5f392f4db9dc5db5", null ],
    [ "main", "hex2otf_8c.html#a0ddf1224851353fc92bfbff6f499fa97", null ],
    [ "matchToken", "hex2otf_8c.html#a4741278aec97f2731e9296930eef938e", null ],
    [ "newBuffer", "hex2otf_8c.html#aefca579e9f2fec4fa23f9907e9633548", null ],
    [ "organizeTables", "hex2otf_8c.html#a049e485562f7f4dfe978c4146ad225b8", null ],
    [ "parseOptions", "hex2otf_8c.html#ac2eec01939cae967aa9882b2517288a1", null ],
    [ "positionGlyphs", "hex2otf_8c.html#af3ba1ba33ebe63ba0340842b7f83021c", null ],
    [ "prepareOffsets", "hex2otf_8c.html#a97af00050b8fd6b7e7b81c7027e4c8e6", null ],
    [ "prepareStringIndex", "hex2otf_8c.html#aa47cc913bb5b8dd3b3665ee5a587d6f7", null ],
    [ "printHelp", "hex2otf_8c.html#a0d20b69b0ad703df78459e1033d5c1d4", null ],
    [ "printVersion", "hex2otf_8c.html#a9c4b081f1e1ad60def15811c71a936f2", null ],
    [ "readCodePoint", "hex2otf_8c.html#ae28f2f636e4d3dd3b5784a3bc3f92b58", null ],
    [ "readGlyphs", "hex2otf_8c.html#ad77c441582f862d494a734eb9855dd41", null ],
    [ "sortGlyphs", "hex2otf_8c.html#a77ff68152c5cb38605010bc7621b0722", null ],
    [ "writeBytes", "hex2otf_8c.html#ae2b46edf2ac290c695e2b27d16f1b380", null ],
    [ "writeFont", "hex2otf_8c.html#a074562f0527ff6db8b1b956b9356a315", null ],
    [ "writeU16", "hex2otf_8c.html#a83aece82aa1fe815fc24a12be34a24b1", null ],
    [ "writeU32", "hex2otf_8c.html#a941153850cde042e39ce40d47d5aac5f", null ],
    [ "allBuffers", "hex2otf_8c.html#a0524ff7f6df40782a03af6d8efd1cf45", null ],
    [ "bufferCount", "hex2otf_8c.html#a91d9682686a5100fae5b0cf362940e14", null ],
    [ "nextBufferIndex", "hex2otf_8c.html#a11ea3753e3a4f90123b78a4b1f731bd4", null ]
];

==> unifont-15.1.03.tar.gz: unifont-15.1.03/doxygen/html/hex2otf_8c.js <==
var hex2otf_8c =
[
    [ "Buffer", "structBuffer.html", null ],
    [ "Glyph", "structGlyph.html", "structGlyph" ],
    [ "Font", "structFont.html", null ],
    [ "Table", "structTable.html", null ],
    [ "TableRecord", "structTableRecord.html", null ],
    [ "Options", "structOptions.html", null ],
    [ "ASCENDER", "hex2otf_8c.html#ad0d9350c8943e5550a14f1cff5580a6c", null ],
    [ "B0", "hex2otf_8c.html#a15c6f2a017088c5db6daac264f992a67", null ],
    [ "B1", "hex2otf_8c.html#a2177c1b55319bb7fd9015fb8b8629ead", null ],
    [ "BX", "hex2otf_8c.html#a77e92e56b5af63bc912ed4cbf5f5c585", null ],
    [ "defineStore", "hex2otf_8c.html#a0e5f5e7d04aec261ae28e2fca801194c", null ],
    [ "DESCENDER", "hex2otf_8c.html#a91005fb187034d042b6bad9c9b1ae7c4", null ],
    [ "FU", "hex2otf_8c.html#a84fd83fab1f19cfb33addaa0557c4682", null ],
    [ "FUPEM", "hex2otf_8c.html#a652fd701381105d0d34ca4084cca413c", null ],
    [ "GLYPH_HEIGHT", "hex2otf_8c.html#a7d0a7ac24105d9c91bce2b5a1e9a1ad3", null ],
    [ "GLYPH_MAX_BYTE_COUNT", "hex2otf_8c.html#ad0f95bf4a3a4a28b173b971e246b8745", null ],
    [ "GLYPH_MAX_WIDTH", "hex2otf_8c.html#a688a4772d61221e9378e5003da51265a", null ],
    [ "MAX_GLYPHS", "hex2otf_8c.html#a1a1d1da8a5f6da54d749399b173c9bfc", null ],
    [ "MAX_NAME_IDS", "hex2otf_8c.html#a06a292e7a76c13c1fa509187a7e6577a", null ],
    [ "PRI_CP", "hex2otf_8c.html#af25acbe53b9070c1400a04c9231691bb", null ],
    [ "PW", "hex2otf_8c.html#a79e768c38f3b21419f01d2d1347523be", null ],
    [ "static_assert", "hex2otf_8c.html#abce67139ad0bc979ef080a694e60fb36", null ],
    [ "U16MAX", "hex2otf_8c.html#a01d5b7bf9004b7a8c920f958861d2a8e", null ],
    [ "U32MAX", "hex2otf_8c.html#a7ccab01e56208030185cefdca13e0ac8", null ],
    [ "VERSION", "hex2otf_8c.html#a1c6d5de492ac61ad29aec7aa9a436bbf", null ],
    [ "Buffer", "hex2otf_8c.html#a7feadaf37f40473cfc76921f8754c0f7", null ],
    [ "byte", "hex2otf_8c.html#a0c8186d9b9b7880309c27230bbb5e69d", null ],
    [ "Font", "hex2otf_8c.html#a6793c760667fe6bf1481f61567954c12", null ],
    [ "Glyph", "hex2otf_8c.html#a8ac383e879c9d7d9af6005444970c837", null ],
    [ "NameStrings", "hex2otf_8c.html#a07c4a43c1a36ee79c8a163298ff9adac", null ],
    [ "Options", "hex2otf_8c.html#a97fbabab590ac85657edb01474da7d50", null ],
    [ "pixels_t", "hex2otf_8c.html#ab9f46992237e1552d3ae221b2a5e95ff", null ],
    [ "Table", "hex2otf_8c.html#aaa5713bb2ecdf81c430009179b806232", null ],
    [ "ContourOp", "hex2otf_8c.html#a25218b5574c0da4a0580647c1a084f38", [
      [ "OP_CLOSE", "hex2otf_8c.html#a25218b5574c0da4a0580647c1a084f38a9e771dc35104ec1246adba881d27e372", null ],
      [ "OP_POINT", "hex2otf_8c.html#a25218b5574c0da4a0580647c1a084f38a01f5371958d06ab1411c46f72f049f45", null ]
    ] ],
    [ "FillSide", "hex2otf_8c.html#a6a06835afab662d1c9fd91960654bb8c", [
      [ "FILL_LEFT", "hex2otf_8c.html#a6a06835afab662d1c9fd91960654bb8caf18243d8ef6a7f601ae03a6cffbabadd", null ],
      [ "FILL_RIGHT", "hex2otf_8c.html#a6a06835afab662d1c9fd91960654bb8ca0bbdc63e5d0938274b80230bc55d03b8", null ]
    ] ],
    [ "LocaFormat", "hex2otf_8c.html#a7da3527c69a413194afdce359b03e1ea", [
      [ "LOCA_OFFSET16", "hex2otf_8c.html#a7da3527c69a413194afdce359b03e1eaa9c5871c30feb10df049d99bd703dfda4", null ],
      [ "LOCA_OFFSET32", "hex2otf_8c.html#a7da3527c69a413194afdce359b03e1eaad5e47b5a6bbf31be31e9b1328e7beef8", null ]
    ] ],
    [ "addTable", "hex2otf_8c.html#a1fab24bb2d2b38b68a38ec871afc3f9c", null ],
    [ "buildOutline", "hex2otf_8c.html#a5af7c9bcfd40e5b11f9d12c40966bb65", null ],
    [ "byCodePoint", "hex2otf_8c.html#a0d187cc87528ef35478afd7a68309f08", null ],
    [ "byTableTag", "hex2otf_8c.html#af1223f39e8627e0a3b0b7b533e6d0b64", null ],
    [ "cacheBuffer", "hex2otf_8c.html#a560637130747e543118ff304389fd18f", null ],
    [ "cacheBytes", "hex2otf_8c.html#a927c31a7e187d15a70667ce6b0ef296a", null ],
    [ "cacheCFFOperand", "hex2otf_8c.html#a51be7f69e0f6053772b3ddacf215df84", null ],
    [ "cacheStringAsUTF16BE", "hex2otf_8c.html#a199befd98ef9ec0ee659d82609abded4", null ],
    [ "cacheU16", "hex2otf_8c.html#a07b29528c561e5852a228c98391225f7", null ],
    [ "cacheU32", "hex2otf_8c.html#a051a88b0ac4eb063945b84e2242408ea", null ],
    [ "cacheU8", "hex2otf_8c.html#a84d7310553d31f4ec587dc001f472834", null ],
    [ "cacheZeros", "hex2otf_8c.html#a0d4560c5d562d31a33f092bb579f8397", null ],
    [ "cleanBuffers", "hex2otf_8c.html#ac947cbe076da5fbab8f5e4c1c821b7a6", null ],
    [ "ensureBuffer", "hex2otf_8c.html#ae32c0f82cbb6a4d8ece0559f1c7b74f4", null ],
    [ "fail", "hex2otf_8c.html#a2f5976201b1e630a94045f04a0348572", null ],
    [ "fillBitmap", "hex2otf_8c.html#afd499a24ff34cb5c19b52df795422c12", null ],
    [ "fillBlankOutline", "hex2otf_8c.html#ab37b4f7111692f8d1163bafd2aab831e", null ],
    [ "fillCFF", "hex2otf_8c.html#a3d62aa29f94c3fa78ca4438739d64a62", null ],
    [ "fillCmapTable", "hex2otf_8c.html#a6362601eb41d051a103a1d9edcd4f284", null ],
    [ "fillGposTable", "hex2otf_8c.html#a6c1e982fdc6c51b9f84051daa2e71936", null ],
    [ "fillGsubTable", "hex2otf_8c.html#a06b8121dea15c8117b7c951ffb22fb7e", null ],
    [ "fillHeadTable", "hex2otf_8c.html#a4ac0c02117b703a71bee3dd34e2eb306", null ],
    [ "fillHheaTable", "hex2otf_8c.html#a28e889c3a36007c2e5d50a498046a6c6", null ],
    [ "fillHmtxTable", "hex2otf_8c.html#a97c9b2ae58f5989d68e639715c3f9df9", null ],
    [ "fillMaxpTable", "hex2otf_8c.html#aff4f28ce178c84c7365245ec10034433", null ],
    [ "fillNameTable", "hex2otf_8c.html#a79d8a322be9d9131b684a9ea67abe05e", null ],
    [ "fillOS2Table", "hex2otf_8c.html#ab6e3bb110dc3e55193c344cb7b56e328", null ],
    [ "fillPostTable", "hex2otf_8c.html#a0ddc03905c4918e04aa1e54a7c1716b1", null ],
    [ "fillTrueType", "hex2otf_8c.html#a326e4fa86eb32bb18e37eab8f495bd2f", null ],
    [ "freeBuffer", "hex2otf_8c.html#ac928f7761fc187ff86f33805309bec21", null ],
    [ "initBuffers", "hex2otf_8c.html#a4cebe6a72365812b5f392f4db9dc5db5", null ],
    [ "main", "hex2otf_8c.html#a0ddf1224851353fc92bfbff6f499fa97", null ],
    [ "matchToken", "hex2otf_8c.html#af1d113ec0d790035476f2743cbf2696f", null ],
    [ "newBuffer", "hex2otf_8c.html#ae8310060f5a9b7cefb84d0bb1b459b64", null ],
    [ "organizeTables", "hex2otf_8c.html#a049e485562f7f4dfe978c4146ad225b8", null ],
    [ "parseOptions", "hex2otf_8c.html#ac2eec01939cae967aa9882b2517288a1", null ],
    [ "positionGlyphs", "hex2otf_8c.html#af3ba1ba33ebe63ba0340842b7f83021c", null ],
    [ "prepareOffsets", "hex2otf_8c.html#a97af00050b8fd6b7e7b81c7027e4c8e6", null ],
    [ "prepareStringIndex", "hex2otf_8c.html#aa52cd46a50cdc2040a72e5c7ecfa944b", null ],
    [ "printHelp", "hex2otf_8c.html#a0d20b69b0ad703df78459e1033d5c1d4", null ],
    [ "printVersion", "hex2otf_8c.html#a9c4b081f1e1ad60def15811c71a936f2", null ],
    [ "readCodePoint", "hex2otf_8c.html#ae28f2f636e4d3dd3b5784a3bc3f92b58", null ],
    [ "readGlyphs", "hex2otf_8c.html#ad77c441582f862d494a734eb9855dd41", null ],
    [ "sortGlyphs", "hex2otf_8c.html#a77ff68152c5cb38605010bc7621b0722", null ],
    [ "writeBytes", "hex2otf_8c.html#ae2b46edf2ac290c695e2b27d16f1b380", null ],
    [ "writeFont", "hex2otf_8c.html#a074562f0527ff6db8b1b956b9356a315", null ],
    [ "writeU16", "hex2otf_8c.html#a83aece82aa1fe815fc24a12be34a24b1", null ],
    [ "writeU32", "hex2otf_8c.html#a941153850cde042e39ce40d47d5aac5f", null ],
    [ "allBuffers", "hex2otf_8c.html#a0524ff7f6df40782a03af6d8efd1cf45", null ],
    [ "bufferCount", "hex2otf_8c.html#a91d9682686a5100fae5b0cf362940e14", null ],
    [ "nextBufferIndex", "hex2otf_8c.html#a11ea3753e3a4f90123b78a4b1f731bd4", null ]
];
